aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--test/test_flowprobe.py5
1 files changed, 4 insertions, 1 deletions
diff --git a/test/test_flowprobe.py b/test/test_flowprobe.py
index ca2bbb53cbc..609099980fc 100644
--- a/test/test_flowprobe.py
+++ b/test/test_flowprobe.py
@@ -421,8 +421,11 @@ class Flowprobe(MethodHolder):
ipfix.remove_vpp_config()
self.logger.info("FFP_TEST_FINISH_0001")
+ @unittest.skipUnless(
+ config.extended, "Test is unstable (assertion error, needs to be fixed"
+ )
def test_0002(self):
"""timer greater than template timeout"""
self.logger.info("FFP_TEST_START_0002")
self.pg_enable_capture(self.pg_interfaces)
self.pkts = []
@@ -421,8 +421,11 @@ class Flowprobe(MethodHolder):
def test_0002(self):
- """timer greater than template timeout"""
+ """timer greater than template timeout [UNSTABLE, FIX ME]"""
self.logger.info("FFP_TEST_START_0002")
self.pg_enable_capture(self.pg_interfaces)